# Changelog

<!--next-version-placeholder-->

## v0.1.0 (2023-11-06)
### Fix
* Semantic_release support for automatic changelog building. ([`6c418d4`](https://github.com/remcoboerma/edwh-web2py-effdted-prio-grid/commit/6c418d4ef4bbdc8eea60f2182e3869339d7f6fef))

### Documentation
* Updated repository links ([`b9ef24d`](https://github.com/remcoboerma/edwh-web2py-effdted-prio-grid/commit/b9ef24dcb50eee4232b3a325735ca2b5929a37d7))
